@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2009, 2023, Oracle and/or its affiliates.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
@@ -34,20 +34,20 @@
 /* #undef HAVE_LIBNSL */
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBSOCKET */
-#define HAVE_LIBDL 1
-#define HAVE_LIBRT 1
+/* #undef HAVE_LIBDL */
+/* #undef HAVE_LIBRT */
 /* #undef HAVE_LIBWRAP */
 /* #undef HAVE_LIBWRAP_PROTOTYPES */
 
 /* Header files */
-#define HAVE_ALLOCA_H 1
+/* #undef HAVE_ALLOCA_H */
 #define HAVE_ARPA_INET_H 1
-#define HAVE_CRYPT_H 1
+/* #undef HAVE_CRYPT_H */
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
-#define HAVE_FPU_CONTROL_H 1
+/* #undef HAVE_FPU_CONTROL_H */
 #define HAVE_GRP_H 1
-/* #undef HAVE_IEEEFP_H */
+#define HAVE_IEEEFP_H 1
 #define HAVE_LANGINFO_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_NETINET_IN_H 1
@@ -62,7 +62,7 @@
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_TERM_H 1
 #define HAVE_TERMIOS_H 1
-#define HAVE_TERMIO_H 1
+/* #undef HAVE_TERMIO_H */
 #define HAVE_UNISTD_H 1
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_SYS_PARAM_H 1
@@ -73,7 +73,7 @@
 /* Libevent */
 /* #undef HAVE_DEVPOLL */
 /* #undef HAVE_SYS_DEVPOLL_H */
-#define HAVE_SYS_EPOLL_H 1
+/* #undef HAVE_SYS_EPOLL_H */
 #define HAVE_TAILQFOREACH 1
 
 /* Functions */
@@ -82,7 +82,7 @@
 /* #undef HAVE_PRINTSTACK */
 #define HAVE_INDEX 1
 #define HAVE_CLOCK_GETTIME 1
-#define HAVE_CUSERID 1
+/* #undef HAVE_CUSERID */
 /* #undef HAVE_DIRECTIO */
 #define HAVE_FTRUNCATE 1
 #define HAVE_COMPRESS 1
@@ -105,18 +105,18 @@
 #define HAVE_GETRLIMIT 1
 #define HAVE_GETRUSAGE 1
 #define HAVE_INITGROUPS 1
-/* #undef HAVE_ISSETUGID */
+#define HAVE_ISSETUGID 1
 #define HAVE_GETUID 1
 #define HAVE_GETEUID 1
 #define HAVE_GETGID 1
 #define HAVE_GETEGID 1
 #define HAVE_LSTAT 1
 #define HAVE_MADVISE 1
-#define HAVE_MALLOC_INFO 1
+/* #undef HAVE_MALLOC_INFO */
 #define HAVE_MEMRCHR 1
 #define HAVE_MLOCK 1
 #define HAVE_MLOCKALL 1
-#define HAVE_MMAP64 1
+/* #undef HAVE_MMAP64 */
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
 #define HAVE_POSIX_MEMALIGN 1
@@ -130,22 +130,22 @@
 #define HAVE_SLEEP 1
 #define HAVE_STPCPY 1
 #define HAVE_STPNCPY 1
-/* #undef HAVE_STRLCPY */
+#define HAVE_STRLCPY 1
 #define HAVE_STRNLEN 1
-/* #undef HAVE_STRLCAT */
+#define HAVE_STRLCAT 1
 #define HAVE_STRSIGNAL 1
-/* #undef HAVE_FGETLN */
+#define HAVE_FGETLN 1
 #define HAVE_STRSEP 1
 /* #undef HAVE_TELL */
 #define HAVE_VASPRINTF 1
-#define HAVE_MEMALIGN 1
+/* #undef HAVE_MEMALIGN */
 #define HAVE_NL_LANGINFO 1
 /* #undef HAVE_HTONLL */
 #define DNS_USE_CPU_CLOCK_FOR_ID 1
-#define HAVE_EPOLL 1
+/* #undef HAVE_EPOLL */
 /* #undef HAVE_EVENT_PORTS */
 #define HAVE_INET_NTOP 1
-/* #undef HAVE_WORKING_KQUEUE */
+#define HAVE_WORKING_KQUEUE 1
 #define HAVE_TIMERADD 1
 #define HAVE_TIMERCLEAR 1
 #define HAVE_TIMERCMP 1
@@ -161,23 +161,23 @@
 #define HAVE_LRAND48 1
 #define GWINSZ_IN_SYS_IOCTL 1
 #define FIONREAD_IN_SYS_IOCTL 1
-/* #undef FIONREAD_IN_SYS_FILIO */
-#define HAVE_SIGEV_THREAD_ID 1
+#define FIONREAD_IN_SYS_FILIO 1
+/* #undef HAVE_SIGEV_THREAD_ID */
 /* #undef HAVE_SIGEV_PORT */
 #define HAVE_LOG2 1
 
 #define HAVE_ISINF 1
 
-/* #undef HAVE_KQUEUE_TIMERS */
-#define HAVE_POSIX_TIMERS 1
+#define HAVE_KQUEUE_TIMERS 1
+/* #undef HAVE_POSIX_TIMERS */
 
 /* Endianess */
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 
 /* Type sizes */
-#define SIZEOF_VOIDP     8
-#define SIZEOF_CHARP     8
-#define SIZEOF_LONG      8
+#define SIZEOF_VOIDP     4
+#define SIZEOF_CHARP     4
+#define SIZEOF_LONG      4
 #define SIZEOF_SHORT     2
 #define SIZEOF_INT       4
 #define SIZEOF_LONG_LONG 8
@@ -187,6 +187,7 @@
 #define HAVE_ULONG 1
 #define HAVE_U_INT32_T 1
 #define HAVE_STRUCT_TIMESPEC
+#define HAVE_TM_GMTOFF 1
 
 /* Support for tagging symbols with __attribute__((visibility("hidden"))) */
 #define HAVE_VISIBILITY_HIDDEN 1
@@ -195,15 +196,15 @@
 #define STACK_DIRECTION -1
 #define TIME_WITH_SYS_TIME 1
 /* #undef NO_FCNTL_NONBLOCK */
-#define HAVE_PAUSE_INSTRUCTION 1
+/* #undef HAVE_PAUSE_INSTRUCTION */
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
-/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
+#define HAVE_HMT_PRIORITY_INSTRUCTION 1
 /* #undef HAVE_ABI_CXA_DEMANGLE */
 #define HAVE_BUILTIN_UNREACHABLE 1
 #define HAVE_BUILTIN_EXPECT 1
 #define HAVE_BUILTIN_STPCPY 1
 #define HAVE_GCC_ATOMIC_BUILTINS 1
-#define HAVE_GCC_SYNC_BUILTINS 1
+/* #undef HAVE_GCC_SYNC_BUILTINS */
 /* #undef HAVE_VALGRIND */
 /* #undef HAVE_PTHREAD_THREADID_NP */
 
@@ -214,23 +215,24 @@
 #define HAVE_IPV6 1
 
 /* #undef ss_family */
-/* #undef HAVE_SOCKADDR_IN_SIN_LEN */
-/* #undef HAVE_SOCKADDR_IN6_SIN6_LEN */
+#define HAVE_SOCKADDR_IN_SIN_LEN 1
+#define HAVE_SOCKADDR_IN6_SIN6_LEN 1
 
 /*
  * Platform specific CMake files
  */
-#define MACHINE_TYPE "x86_64"
-#define HAVE_LINUX_LARGE_PAGES 1
+#define MACHINE_TYPE "powerpc"
+/* #undef HAVE_LINUX_LARGE_PAGES */
 /* #undef HAVE_SOLARIS_LARGE_PAGES */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
-#define SYSTEM_TYPE "Linux"
+#define SYSTEM_TYPE "NetBSD"
 /* Windows stuff, mostly functions, that have Posix analogs but named differently */
 /* #undef IPPROTO_IPV6 */
 /* #undef IPV6_V6ONLY */
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
+/* #undef APPLE_ARM */
 
 /*
  * From main CMakeLists.txt
@@ -243,14 +245,14 @@
 /* #undef HAVE_ASAN */
 /* #undef ENABLED_LOCAL_INFILE */
 #define OPTIMIZER_TRACE 1
-#define DEFAULT_MYSQL_HOME "/2022Q2"
-#define SHAREDIR "/2022Q2/share/mysql"
-#define DEFAULT_BASEDIR "/2022Q2"
-#define MYSQL_DATADIR "/2022Q2/var/mysql"
-#define MYSQL_KEYRINGDIR "/2022Q2/keyring"
-#define DEFAULT_CHARSET_HOME "/2022Q2"
-#define PLUGINDIR "/2022Q2/lib/mysql/plugin"
-#define DEFAULT_SYSCONFDIR "/2022Q2/etc"
+#define DEFAULT_MYSQL_HOME "/usr/pkg"
+#define SHAREDIR "/usr/pkg/share/mysql"
+#define DEFAULT_BASEDIR "/usr/pkg"
+#define MYSQL_DATADIR "/var/mysql"
+#define MYSQL_KEYRINGDIR "/usr/pkg/keyring"
+#define DEFAULT_CHARSET_HOME "/usr/pkg"
+#define PLUGINDIR "/usr/pkg/lib/mysql/plugin"
+#define DEFAULT_SYSCONFDIR "/usr/pkg/etc"
 #define DEFAULT_TMPDIR P_tmpdir
 #define INSTALL_SBINDIR "/usr/local/mysql/sbin"
 #define INSTALL_BINDIR "/usr/local/mysql/bin"
@@ -379,9 +381,9 @@
  * syscall
 */
 /* #undef HAVE_SYS_THREAD_SELFID */
-#define HAVE_SYS_GETTID 1
+/* #undef HAVE_SYS_GETTID */
 /* #undef HAVE_PTHREAD_GETTHREADID_NP */
-#define HAVE_PTHREAD_SETNAME_NP 1
+/* #undef HAVE_PTHREAD_SETNAME_NP */
 #define HAVE_INTEGER_PTHREAD_SELF 1
 
 /* Platform-specific C++ compiler behaviors we rely upon */
@@ -403,15 +405,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 38
+#define MYSQL_VERSION_PATCH 44
 #define MYSQL_VERSION_EXTRA ""
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.38"
+#define PACKAGE_STRING "MySQL Server 5.7.44"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.38"
-#define VERSION "5.7.38"
+#define PACKAGE_VERSION "5.7.44"
+#define VERSION "5.7.44"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -419,7 +421,6 @@
  */
 #define CPU_LEVEL1_DCACHE_LINESIZE 64
 
-
 /*
  * NDB
  */
